@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; frozen_string_literal: true -*-
 #
 #--
-# Copyright (C) 2009-2016 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2019 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -21,7 +21,7 @@ module Kramdown
         if !after_block_boundary?
           return false
         elsif @src[1]
-          @src.scan(/^#{OPT_SPACE}\\/) if @src[3]
+          @src.scan(/^#{OPT_SPACE}\\/o) if @src[3]
           return false
         end
 
@@ -29,7 +29,7 @@ module Kramdown
         @src.pos += @src.matched_size
         data = @src[2].strip
         if before_block_boundary?
-          @tree.children << new_block_el(:math, data, nil, :category => :block, :location => start_line_number)
+          @tree.children << new_block_el(:math, data, nil, category: :block, location: start_line_number)
           true
         else
           @src.revert_pos(saved_pos)
@@ -38,14 +38,13 @@ module Kramdown
       end
       define_parser(:block_math, BLOCK_MATH_START)
 
-
       INLINE_MATH_START = /\$\$(.*?)\$\$/m
 
       # Parse the inline math at the current location.
       def parse_inline_math
         start_line_number = @src.current_line_number
         @src.pos += @src.matched_size
-        @tree.children << Element.new(:math, @src[1].strip, nil, :category => :span, :location => start_line_number)
+        @tree.children << Element.new(:math, @src[1].strip, nil, category: :span, location: start_line_number)
       end
       define_parser(:inline_math, INLINE_MATH_START, '\$')
 
